==> 1.0.1.tar.gz: lib/src/observer.dart <==
import 'package:flutter/widgets.dart';
import 'package:observable_pattern/src/observable.dart';

//Builder interface to build a widget and rebuild values when a value change from Observable object
typedef _ObservableBuilder<T, E> = Widget Function(
    BuildContext context, T value, E error);

//Observer widget class receive an observable and a builder to rebuild when a value change from Observable object
class Observer<T, E> extends StatefulWidget {
  final Observable<T, E> observable;
  final _ObservableBuilder builder;

  const Observer({
    Key key,
    this.observable,
    @required this.builder,
  })  : assert(builder != null),
        super(key: key);

  @override
  _ObserverState<T, E> createState() => _ObserverState<T, E>();
}

class _ObserverState<T, E> extends State<Observer<T, E>> {
  @override
  void initState() {
    super.initState();
    widget.observable?.addListener(_init);
  }

  void _init(_) {
    if (mounted) setState(() {});
  }

  @override
  void didUpdateWidget(Observer<T, E> oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (oldWidget.observable != widget.observable) {
      oldWidget.observable?.removeListener(_init);
      widget.observable?.addListener(_init);
    }
  }

  @override
  void dispose() {
    widget.observable?.removeListener(_init);
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    final child = widget.builder(
        context, widget.observable?.value, widget.observable?.error);
    assert(child != null);
    return child;
  }
}

==> 1.0.4.tar.gz: lib/src/observer.dart <==
import 'package:flutter/widgets.dart';
import 'package:observable_pattern/src/observable.dart';

//Builder interface to build a widget and rebuild values when a value change from Observable object
typedef _ObservableBuilder<T, E> = Widget Function(
    BuildContext context, T value, E error);

//Observer widget class receive an observable and a builder to rebuild when a value change from Observable object
class Observer<T, E> extends StatefulWidget {
  final Observable<T, E> observable;
  final _ObservableBuilder<T, E> builder;

  const Observer({
    Key key,
    this.observable,
    @required this.builder,
  })  : assert(builder != null),
        super(key: key);

  @override
  _ObserverState<T, E> createState() => _ObserverState<T, E>();
}

class _ObserverState<T, E> extends State<Observer<T, E>> {
  @override
  void initState() {
    super.initState();
    widget.observable?.addListener(init);
  }

  void init(_) {
    if (mounted) {
      setState(() {});
    }
  }

  @override
  void didUpdateWidget(Observer<T, E> oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (oldWidget.observable != widget.observable) {
      oldWidget.observable?.removeListener(init);
      widget.observable?.addListener(init);
    }
  }

  @override
  void dispose() {
    widget.observable?.removeListener(init);
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    final child = widget.builder(
        context, widget.observable?.value, widget.observable?.error);
    assert(child != null);
    return child;
  }
}
